@@ -8,12 +8,12 @@
  * modify it under the terms of the GNU General Public License
  * as published by the Free Software Foundation; either version 2
  * of the License, or (at your option) any later version.
-
+ *
  * This program is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  * GNU General Public License for more details.
-
+ *
  * You should have received a copy of the GNU General Public License
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
@@ -46,6 +46,8 @@
 #include "agi/keyboard.h"
 #include "agi/menu.h"
 
+#include "gui/predictivedialog.h"
+
 namespace Agi {
 
 void AgiEngine::allowSynthetic(bool allow) {
@@ -58,9 +60,25 @@ void AgiEngine::processEvents() {
 
 	while (_eventMan->pollEvent(event)) {
 		switch (event.type) {
-		case Common::EVENT_PREDICTIVE_DIALOG:
-			if (_predictiveDialogRunning)
-				break;
+		case Common::EVENT_PREDICTIVE_DIALOG: {
+			GUI::PredictiveDialog _predictiveDialog;
+			_predictiveDialog.runModal();
+			strcpy(_predictiveResult, _predictiveDialog.getResult());
+			if (strcmp(_predictiveResult, "")) {
+				if (_game.inputMode == INPUT_NORMAL) {
+					strcpy((char *)_game.inputBuffer, _predictiveResult);
+					handleKeys(KEY_ENTER);
+				} else if (_game.inputMode == INPUT_GETSTRING) {
+					strcpy(_game.strings[_stringdata.str], _predictiveResult);
+					newInputMode(INPUT_NORMAL);
+					_gfx->printCharacter(_stringdata.x + strlen(_game.strings[_stringdata.str]) + 1,
+							_stringdata.y, ' ', _game.colorFg, _game.colorBg);
+				} else if (_game.inputMode == INPUT_NONE) {
+					for (int n = 0; _predictiveResult[n]; n++)
+						keyEnqueue(_predictiveResult[n]);
+				}
+			}
+			/*
 			if (predictiveDialog()) {
 				if (_game.inputMode == INPUT_NORMAL) {
 					strcpy((char *)_game.inputBuffer, _predictiveResult);
@@ -75,6 +93,8 @@ void AgiEngine::processEvents() {
 						keyEnqueue(_predictiveResult[n]);
 				}
 			}
+			*/
+			}
 			break;
 		case Common::EVENT_LBUTTONDOWN:
 			key = BUTTON_LEFT;
@@ -131,65 +151,46 @@ void AgiEngine::processEvents() {
 			switch (key = event.kbd.keycode) {
 			case Common::KEYCODE_LEFT:
 			case Common::KEYCODE_KP4:
-				if (_predictiveDialogRunning && key == Common::KEYCODE_KP4)
-					key = event.kbd.ascii;
-				else if (_allowSynthetic || !event.synthetic)
+				if (_allowSynthetic || !event.synthetic)
 					key = KEY_LEFT;
 				break;
 			case Common::KEYCODE_RIGHT:
 			case Common::KEYCODE_KP6:
-				if (_predictiveDialogRunning && key == Common::KEYCODE_KP6)
-					key = event.kbd.ascii;
-				else if (_allowSynthetic || !event.synthetic)
+				if (_allowSynthetic || !event.synthetic)
 					key = KEY_RIGHT;
 				break;
 			case Common::KEYCODE_UP:
 			case Common::KEYCODE_KP8:
-				if (_predictiveDialogRunning && key == Common::KEYCODE_KP8)
-					key = event.kbd.ascii;
-				else if (_allowSynthetic || !event.synthetic)
+				if (_allowSynthetic || !event.synthetic)
 					key = KEY_UP;
 				break;
 			case Common::KEYCODE_DOWN:
 			case Common::KEYCODE_KP2:
-				if (_predictiveDialogRunning && key == Common::KEYCODE_KP2)
-					key = event.kbd.ascii;
-				else if (_allowSynthetic || !event.synthetic)
+				if (_allowSynthetic || !event.synthetic)
 					key = KEY_DOWN;
 				break;
 			case Common::KEYCODE_PAGEUP:
 			case Common::KEYCODE_KP9:
-				if (_predictiveDialogRunning && key == Common::KEYCODE_KP9)
-					key = event.kbd.ascii;
-				else if (_allowSynthetic || !event.synthetic)
+				if (_allowSynthetic || !event.synthetic)
 					key = KEY_UP_RIGHT;
 				break;
 			case Common::KEYCODE_PAGEDOWN:
 			case Common::KEYCODE_KP3:
-				if (_predictiveDialogRunning && key == Common::KEYCODE_KP3)
-					key = event.kbd.ascii;
-				else if (_allowSynthetic || !event.synthetic)
+				if (_allowSynthetic || !event.synthetic)
 					key = KEY_DOWN_RIGHT;
 				break;
 			case Common::KEYCODE_HOME:
 			case Common::KEYCODE_KP7:
-				if (_predictiveDialogRunning && key == Common::KEYCODE_KP7)
-					key = event.kbd.ascii;
-				else if (_allowSynthetic || !event.synthetic)
+				if (_allowSynthetic || !event.synthetic)
 					key = KEY_UP_LEFT;
 				break;
 			case Common::KEYCODE_END:
 			case Common::KEYCODE_KP1:
-				if (_predictiveDialogRunning && key == Common::KEYCODE_KP1)
-					key = event.kbd.ascii;
-				else if (_allowSynthetic || !event.synthetic)
+				if (_allowSynthetic || !event.synthetic)
 					key = KEY_DOWN_LEFT;
 				break;
 			case Common::KEYCODE_KP5:
-				if (_predictiveDialogRunning)
-					key = event.kbd.ascii;
-				else
-					key = KEY_STATIONARY;
+				key = KEY_STATIONARY;
 				break;
 			case Common::KEYCODE_PLUS:
 				key = '+';
@@ -250,19 +251,7 @@ void AgiEngine::processEvents() {
 				// Not a special key, so get the ASCII code for it
 				key = event.kbd.ascii;
 
-				// Function isalpha is defined in <ctype.h> so the following applies to it:
-				//
-				// The C Programming Language Standard states:
-				//   The header <ctype.h> declares several functions useful for classifying
-				//   and mapping characters. In all cases the argument is an int, the value
-				//   of which shall be representable as an unsigned char or shall equal the
-				//   value of the macro EOF. If the argument has any other value, the
-				//   behavior is undefined.
-				//
-				// For a concrete example (e.g. in Microsoft Visual Studio 2003):
-				//   When used with a debug CRT library, isalpha will display a CRT assert
-				//   if passed a parameter that isn't EOF or in the range of 0 through 0xFF.
-				if (key >= 0 && key <= 0xFF && isalpha(key)) {
+				if (Common::isAlpha(key)) {
 					// Key is A-Z.
 					// Map Ctrl-A to 1, Ctrl-B to 2, etc.
 					if (event.kbd.flags & Common::KBD_CTRL) {
@@ -422,7 +411,9 @@ int AgiEngine::agiInit() {
 #ifdef __DS__
 	// Normally, the engine loads the predictive text dictionary when the predictive dialog
 	// is shown.  On the DS version, the word completion feature needs the dictionary too.
-	loadDict();
+
+	// FIXME - loadDict() no long exists in AGI as this has been moved to within the
+	// GUI Predictive Dialog, but DS Word Completion is probably broken due to this...
 #endif
 
 	_egoHoldKey = false;
@@ -507,6 +498,9 @@ static const GameSettings agiSettings[] = {
 };
 
 AgiBase::AgiBase(OSystem *syst, const AGIGameDescription *gameDesc) : Engine(syst), _gameDescription(gameDesc) {
+	// Assign default values to the config manager, in case settings are missing
+	ConfMan.registerDefault("originalsaveload", "false");
+
 	_noSaveLoadAllowed = false;
 
 	_rnd = new Common::RandomSource("agi");
@@ -519,10 +513,7 @@ AgiBase::AgiBase(OSystem *syst, const AGIGameDescription *gameDesc) : Engine(sys
 AgiBase::~AgiBase() {
 	delete _rnd;
 
-	if (_sound) {
-		_sound->deinitSound();
-		delete _sound;
-	}
+	delete _sound;
 }
 
 void AgiBase::initRenderMode() {
@@ -587,10 +578,6 @@ AgiEngine::AgiEngine(OSystem *syst, const AGIGameDescription *gameDesc) : AgiBas
 
 	_oldMode = INPUT_NONE;
 
-	_predictiveDialogRunning = false;
-	_predictiveDictText = NULL;
-	_predictiveDictLine = NULL;
-	_predictiveDictLineCount = 0;
 	_firstSlot = 0;
 
 	resetControllers();
@@ -598,6 +585,21 @@ AgiEngine::AgiEngine(OSystem *syst, const AGIGameDescription *gameDesc) : AgiBas
 	setupOpcodes();
 	_game._curLogic = NULL;
 	_timerHack = 0;
+
+	_lastSaveTime = 0;
+	_lastTick = 0;
+
+	memset(_keyQueue, 0, sizeof(_keyQueue));
+	memset(_predictiveResult, 0, sizeof(_predictiveResult));
+
+	_sprites = NULL;
+	_picture = NULL;
+	_loader = NULL;
+	_console = NULL;
+
+	_egoHoldKey = false;
+
+
 }
 
 void AgiEngine::initialize() {
@@ -660,7 +662,6 @@ void AgiEngine::initialize() {
 	_game.sbuf     = _game.sbuf16c; // Make sbuf point to the 16 color (+control line & priority info) AGI screen by default
 
 	_gfx->initVideo();
-	_sound->initSound();
 
 	_lastSaveTime = 0;
 
@@ -696,9 +697,6 @@ AgiEngine::~AgiEngine() {
 	_gfx->deinitMachine();
 	delete _gfx;
 	delete _console;
-
-	free(_predictiveDictLine);
-	free(_predictiveDictText);
 }
 
 Common::Error AgiBase::init() {
@@ -715,6 +713,7 @@ Common::Error AgiBase::init() {
 
 Common::Error AgiEngine::go() {
 	CursorMan.showMouse(true);
+	setTotalPlayTime(0);
 
 	if (_game.state < STATE_LOADED) {
 		do {
