@@ -8,12 +8,12 @@
  * modify it under the terms of the GNU General Public License
  * as published by the Free Software Foundation; either version 2
  * of the License, or (at your option) any later version.
-
+ *
  * This program is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  * GNU General Public License for more details.
-
+ *
  * You should have received a copy of the GNU General Public License
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
@@ -40,8 +40,8 @@ namespace Kyra {
 KyraEngine_LoK::KyraEngine_LoK(OSystem *system, const GameFlags &flags)
 	: KyraEngine_v1(system, flags) {
 
-	_seq_Forest = _seq_KallakWriting = _seq_KyrandiaLogo = _seq_KallakMalcolm =
-	_seq_MalcolmTree = _seq_WestwoodLogo = _seq_Demo1 = _seq_Demo2 = _seq_Demo3 =
+	_seq_Forest = _seq_KallakWriting = _seq_KyrandiaLogo = _seq_KallakMalcolm = 0;
+	_seq_MalcolmTree = _seq_WestwoodLogo = _seq_Demo1 = _seq_Demo2 = _seq_Demo3 = 0;
 	_seq_Demo4 = 0;
 
 	_seq_WSATable = _seq_CPSTable = _seq_COLTable = _seq_textsTable = 0;
@@ -98,8 +98,6 @@ KyraEngine_LoK::KyraEngine_LoK(OSystem *system, const GameFlags &flags)
 
 	_malcolmFrame = 0;
 	_malcolmTimer1 = _malcolmTimer2 = 0;
-
-	_soundFiles = 0;
 }
 
 KyraEngine_LoK::~KyraEngine_LoK() {
@@ -123,8 +121,6 @@ KyraEngine_LoK::~KyraEngine_LoK() {
 	delete _animator;
 	delete _seq;
 
-	delete[] _soundFiles;
-
 	delete[] _characterList;
 
 	delete[] _roomTable;
@@ -167,13 +163,16 @@ KyraEngine_LoK::~KyraEngine_LoK() {
 }
 
 Common::Error KyraEngine_LoK::init() {
-	if (_flags.platform == Common::kPlatformPC98 && _flags.useHiResOverlay && ConfMan.getBool("16_color"))
+	if (Common::parseRenderMode(ConfMan.get("render_mode")) == Common::kRenderPC9801)
 		_screen = new Screen_LoK_16(this, _system);
 	else
 		_screen = new Screen_LoK(this, _system);
 	assert(_screen);
 	_screen->setResolution();
 
+	_debugger = new Debugger_LoK(this);
+	assert(_debugger);
+
 	KyraEngine_v1::init();
 
 	_sprites = new Sprites(this, _system);
@@ -191,7 +190,7 @@ Common::Error KyraEngine_LoK::init() {
 
 	initStaticResource();
 
-	_sound->setSoundList(&_soundData[kMusicIntro]);
+	_sound->selectAudioResourceSet(kMusicIntro);
 
 	if (_flags.platform == Common::kPlatformAmiga) {
 		_trackMap = _amigaTrackMap;
@@ -212,7 +211,7 @@ Common::Error KyraEngine_LoK::init() {
 	_currentCharacter = 0;
 	_characterList = new Character[11];
 	assert(_characterList);
-	memset(_characterList, 0, sizeof(Character)*11);
+	memset(_characterList, 0, sizeof(Character) * 11);
 
 	for (int i = 0; i < 11; ++i)
 		memset(_characterList[i].inventoryItems, 0xFF, sizeof(_characterList[i].inventoryItems));
@@ -229,8 +228,6 @@ Common::Error KyraEngine_LoK::init() {
 	memset(&_scriptMain, 0, sizeof(EMCState));
 	memset(&_scriptClick, 0, sizeof(EMCState));
 
-	_debugger = new Debugger_LoK(this);
-	assert(_debugger);
 	memset(_shapes, 0, sizeof(_shapes));
 
 	for (int i = 0; i < ARRAYSIZE(_movieObjects); ++i)
@@ -254,7 +251,7 @@ Common::Error KyraEngine_LoK::init() {
 	_poisonDeathCounter = 0;
 
 	memset(_itemHtDat, 0, sizeof(_itemHtDat));
-	memset(_exitList, 0xFFFF, sizeof(_exitList));
+	memset(_exitList, 0xFF, sizeof(_exitList));
 	_exitListPtr = 0;
 	_pathfinderFlag = _pathfinderFlag2 = 0;
 	_lastFindWayRet = 0;
@@ -348,7 +345,7 @@ void KyraEngine_LoK::startup() {
 	static const uint8 colorMap[] = { 0, 0, 0, 0, 12, 12, 12, 0, 0, 0, 0, 0 };
 	_screen->setTextColorMap(colorMap);
 
-	_sound->setSoundList(&_soundData[kMusicIngame]);
+	_sound->selectAudioResourceSet(kMusicIngame);
 	if (_flags.platform == Common::kPlatformPC98)
 		_sound->loadSoundFile("SE.DAT");
 	else
@@ -369,7 +366,7 @@ void KyraEngine_LoK::startup() {
 	// XXX
 	for (int i = 0; i < 12; ++i) {
 		int size = _screen->getRectSize(3, 24);
-		_shapes[361+i] = new byte[size];
+		_shapes[361 + i] = new byte[size];
 	}
 
 	_itemBkgBackUp[0] = new uint8[_screen->getRectSize(3, 24)];
@@ -436,6 +433,9 @@ void KyraEngine_LoK::startup() {
 }
 
 void KyraEngine_LoK::mainLoop() {
+	// Initialize debugger since how it should be fully usable
+	_debugger->initialize();
+
 	_eventList.clear();
 
 	while (!shouldQuit()) {
@@ -450,10 +450,8 @@ void KyraEngine_LoK::mainLoop() {
 		if (_deathHandler != -1) {
 			snd_playWanderScoreViaMap(0, 1);
 			snd_playSoundEffect(49);
-			_screen->hideMouse();
 			_screen->setMouseCursor(1, 1, _shapes[0]);
 			removeHandItem();
-			_screen->showMouse();
 			_gui->buttonMenuCallback(0);
 			_deathHandler = -1;
 		}
@@ -506,6 +504,9 @@ void KyraEngine_LoK::delay(uint32 amount, bool update, bool isMainLoop) {
 			updateTextFade();
 			updateMousePointer();
 		} else {
+			// We need to do Screen::updateScreen here, since client code
+			// relies on this method to copy screen changes to the actual
+			// screen since at least 0af418e7ea3a41f93fcc551a45ee5bae822d812a.
 			_screen->updateScreen();
 		}
 
@@ -578,23 +579,23 @@ void KyraEngine_LoK::setupShapes123(const Shape *shapeTable, int endShape, int f
 
 	uint8 curImage = 0xFF;
 	int curPageBackUp = _screen->_curPage;
-	_screen->_curPage = 8;	// we are using page 8 here in the original page 2 was backuped and then used for this stuff
+	_screen->_curPage = 8;  // we are using page 8 here in the original page 2 was backuped and then used for this stuff
 	int shapeFlags = 2;
 	if (flags)
 		shapeFlags = 3;
-	for (int i = 123; i < 123+endShape; ++i) {
-		uint8 newImage = shapeTable[i-123].imageIndex;
+	for (int i = 123; i < 123 + endShape; ++i) {
+		uint8 newImage = shapeTable[i - 123].imageIndex;
 		if (newImage != curImage && newImage != 0xFF) {
 			assert(_characterImageTable);
 			_screen->loadBitmap(_characterImageTable[newImage], 8, 8, 0);
 			curImage = newImage;
 		}
-		_shapes[i] = _screen->encodeShape(shapeTable[i-123].x<<3, shapeTable[i-123].y, shapeTable[i-123].w<<3, shapeTable[i-123].h, shapeFlags);
-		assert(i-7 < _defaultShapeTableSize);
-		_defaultShapeTable[i-7].xOffset = shapeTable[i-123].xOffset;
-		_defaultShapeTable[i-7].yOffset = shapeTable[i-123].yOffset;
-		_defaultShapeTable[i-7].w = shapeTable[i-123].w;
-		_defaultShapeTable[i-7].h = shapeTable[i-123].h;
+		_shapes[i] = _screen->encodeShape(shapeTable[i - 123].x << 3, shapeTable[i - 123].y, shapeTable[i - 123].w << 3, shapeTable[i - 123].h, shapeFlags);
+		assert(i - 7 < _defaultShapeTableSize);
+		_defaultShapeTable[i - 7].xOffset = shapeTable[i - 123].xOffset;
+		_defaultShapeTable[i - 7].yOffset = shapeTable[i - 123].yOffset;
+		_defaultShapeTable[i - 7].w = shapeTable[i - 123].w;
+		_defaultShapeTable[i - 7].h = shapeTable[i - 123].h;
 	}
 	_screen->_curPage = curPageBackUp;
 }
@@ -699,7 +700,6 @@ int KyraEngine_LoK::processInputHelper(int xpos, int ypos) {
 	uint8 item = findItemAtPos(xpos, ypos);
 	if (item != 0xFF) {
 		if (_itemInHand == kItemNone) {
-			_screen->hideMouse();
 			_animator->animRemoveGameItem(item);
 			snd_playSoundEffect(53);
 			assert(_currentCharacter->sceneId < _roomTableSize);
@@ -710,7 +710,6 @@ int KyraEngine_LoK::processInputHelper(int xpos, int ypos) {
 			assert(_itemList && _takenList);
 			updateSentenceCommand(_itemList[getItemListIndex(item2)], _takenList[0], 179);
 			_itemInHand = item2;
-			_screen->showMouse();
 			clickEventHandler2();
 			return 1;
 		} else {
@@ -784,7 +783,7 @@ void KyraEngine_LoK::updateMousePointer(bool forceUpdate) {
 	}
 
 	if (mouse.x >= _entranceMouseCursorTracks[0] && mouse.y >= _entranceMouseCursorTracks[1]
-		&& mouse.x <= _entranceMouseCursorTracks[2] && mouse.y <= _entranceMouseCursorTracks[3]) {
+	        && mouse.x <= _entranceMouseCursorTracks[2] && mouse.y <= _entranceMouseCursorTracks[3]) {
 		switch (_entranceMouseCursorTracks[4]) {
 		case 0:
 			newMouseState = -6;
@@ -827,21 +826,17 @@ void KyraEngine_LoK::updateMousePointer(bool forceUpdate) {
 
 	if ((newMouseState && _mouseState != newMouseState) || (newMouseState && forceUpdate)) {
 		_mouseState = newMouseState;
-		_screen->hideMouse();
 		_screen->setMouseCursor(newX, newY, _shapes[shape]);
-		_screen->showMouse();
 	}
 
 	if (!newMouseState) {
 		if (_mouseState != _itemInHand || forceUpdate) {
 			if (mouse.y > 158 || (mouse.x >= 12 && mouse.x < 308 && mouse.y < 136 && mouse.y >= 12) || forceUpdate) {
 				_mouseState = _itemInHand;
-				_screen->hideMouse();
 				if (_itemInHand == kItemNone)
 					_screen->setMouseCursor(1, 1, _shapes[0]);
 				else
-					_screen->setMouseCursor(8, 15, _shapes[216+_itemInHand]);
-				_screen->showMouse();
+					_screen->setMouseCursor(8, 15, _shapes[216 + _itemInHand]);
 			}
 		}
 	}
@@ -880,8 +875,8 @@ int KyraEngine_LoK::checkForNPCScriptRun(int xpos, int ypos) {
 	int charLeft = 0, charRight = 0, charTop = 0, charBottom = 0;
 
 	int scaleFactor = _scaleTable[currentChar->y1];
-	int addX = (((scaleFactor*8)*3)>>8)>>1;
-	int addY = ((scaleFactor*3)<<4)>>8;
+	int addX = (((scaleFactor * 8) * 3) >> 8) >> 1;
+	int addY = ((scaleFactor * 3) << 4) >> 8;
 
 	charLeft = currentChar->x1 - addX;
 	charRight = currentChar->x1 + addX;
@@ -904,7 +899,7 @@ int KyraEngine_LoK::checkForNPCScriptRun(int xpos, int ypos) {
 		charRight = currentChar->x1 + 11;
 		charTop = currentChar->y1 - 48;
 		// if (!i)
-		//	charBottom = currentChar->y2 - 16;
+		//  charBottom = currentChar->y2 - 16;
 		// else
 		charBottom = currentChar->y1;
 
@@ -953,9 +948,6 @@ void KyraEngine_LoK::registerDefaultSettings() {
 	// Most settings already have sensible defaults. This one, however, is
 	// specific to the Kyra engine.
 	ConfMan.registerDefault("walkspeed", 2);
-
-	if (_flags.platform == Common::kPlatformPC98 && _flags.useHiResOverlay)
-		ConfMan.registerDefault("16_color", false);
 }
 
 void KyraEngine_LoK::readSettings() {
@@ -964,13 +956,13 @@ void KyraEngine_LoK::readSettings() {
 	// The default talk speed is 60. This should be mapped to "Normal".
 
 	if (talkspeed == 0)
-		_configTextspeed = 3;	// Clickable
+		_configTextspeed = 3;   // Clickable
 	if (talkspeed <= 50)
-		_configTextspeed = 0;	// Slow
+		_configTextspeed = 0;   // Slow
 	else if (talkspeed <= 150)
-		_configTextspeed = 1;	// Normal
+		_configTextspeed = 1;   // Normal
 	else
-		_configTextspeed = 2;	// Fast
+		_configTextspeed = 2;   // Fast
 
 	KyraEngine_v1::readSettings();
 }
@@ -979,16 +971,16 @@ void KyraEngine_LoK::writeSettings() {
 	int talkspeed;
 
 	switch (_configTextspeed) {
-	case 0:		// Slow
+	case 0:     // Slow
 		talkspeed = 1;
 		break;
-	case 1:		// Normal
+	case 1:     // Normal
 		talkspeed = 60;
 		break;
-	case 2:		// Fast
+	case 2:     // Fast
 		talkspeed = 255;
 		break;
-	default:	// Clickable
+	default:    // Clickable
 		talkspeed = 0;
 	}
 
