@@ -8,19 +8,16 @@
  * modify it under the terms of the GNU General Public License
  * as published by the Free Software Foundation; either version 2
  * of the License, or (at your option) any later version.
-
+ *
  * This program is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  * GNU General Public License for more details.
-
+ *
  * You should have received a copy of the GNU General Public License
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
  *
- * $URL$
- * $Id$
- *
  */
 
 #include "lure/memory.h"
@@ -96,8 +93,12 @@ void MemoryBlock::copyFrom(const byte *src, uint32 srcPos, uint32 destPos, uint3
 
 void MemoryBlock::reallocate(uint32 size1) {
 	_size = size1;
-	_data = (byte *) realloc(_data, size1);
-	if (!_data) error ("Failed reallocating memory block");
+
+	byte *tmp = (byte *) realloc(_data, size1);
+	if (!tmp)
+		error ("[MemoryBlock::reallocate] Failed reallocating memory block");
+
+	_data = tmp;
 }
 
 } // End of namespace Lure
