@@ -18,8 +18,6 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
  *
- * $URL$
- * $Id$
  */
 
 #include "common/events.h"
@@ -86,11 +84,10 @@ struct keycodeToChar {
 
 char EventTests::keystrokeToChar() {
 	Common::EventManager *eventMan = g_system->getEventManager();
-	bool quitLoop = false;
 	Common::Event event;
 
 	// handle all keybd events
-	while (!quitLoop) {
+	while (true) {
 		while (eventMan->pollEvent(event)) {
 			// Quit if explicitly requested!
 			if (Engine::shouldQuit()) {
@@ -113,8 +110,6 @@ char EventTests::keystrokeToChar() {
 			}
 		}
 	}
-
-	return 0;
 }
 
 Common::Rect EventTests::drawFinishZone() {
